<?php 
$lan = array(

  "loading" => "Carregando",
  "done" => "Conclu&iacute;do",
  "name_empty" => "O campo Nome n&atilde;o pode ficar em branco:",
  "name_not_unique" => "Nome j&aacute; existe",
  "continue" => "Continuar",
  'add' => 'Adicionar',

);
?>
